web/test/unittest_views_editforms.py
changeset 2637 07103211e511
parent 2058 7ef12c03447c
child 2643 9976f511003b
--- a/web/test/unittest_views_editforms.py	Sat Aug 01 17:20:26 2009 +0200
+++ b/web/test/unittest_views_editforms.py	Sat Aug 01 17:21:19 2009 +0200
@@ -25,12 +25,12 @@
         AEF.rfields_kwargs.del_rtag('CWUser', 'login', '*', 'subject')
 
 
-    def test_euser_relations_by_category(self):
+    def test_cwuser_relations_by_category(self):
         #for (rtype, role, stype, otype), tag in AEF.rcategories._tagdefs.items():
         #    if rtype == 'tags':
         #        print rtype, role, stype, otype, ':', tag
         e = self.etype_instance('CWUser')
         # see custom configuration in views.euser
         self.assertEquals(rbc(e, 'primary'),
                           [('login', 'subject'),
                            ('upassword', 'subject'),
@@ -46,6 +46,7 @@
                               [('last_login_time', 'subject'),
                                ('created_by', 'subject'),
                                ('creation_date', 'subject'),
+                               ('cwuri', 'subject'),
                                ('modification_date', 'subject'),
                                ('owned_by', 'subject'),
                                ('bookmarked_by', 'object'),
@@ -97,6 +98,7 @@
         self.assertListEquals(rbc(e, 'metadata'),
                               [('created_by', 'subject'),
                                ('creation_date', 'subject'),
+                               ('cwuri', 'subject'),
                                ('modification_date', 'subject'),
                                ('owned_by', 'subject'),
                                ])
@@ -158,3 +160,4 @@
 
 if __name__ == '__main__':
     unittest_main()
+
@@ -25,12 +25,12 @@
         #        print rtype, role, stype, otype, ':', tag
         e = self.etype_instance('CWUser')
-        # see custom configuration in views.euser
+        # see custom configuration in views.cwuser
         self.assertEquals(rbc(e, 'primary'),
                           [('login', 'subject'),